frezchem.dat is a database from Jonathon Toner and the
developers for the frezchem code (Toner and Sletten (2013), Marion
and coworkers). Frezchem is a Pitzer model for temperatures of 0 C
and below.
phrLoadDatabaseString.
frezchem.dat # phrLoadDatabaseString(frezchem.dat)Other Databases:
Amm.dat,
ColdChem.dat,
Tipping_Hurley.dat,
core10.dat,
ex15.dat,
iso.dat,
llnl.dat,
minteq.dat,
minteq.v4.dat,
phreeqc.dat,
pitzer.dat,
sit.dat,
wateq4f.dat